diff --git a/tools/urlfieldtests/report_generation.py b/tools/urlfieldtests/report_generation.py
new file mode 100644
index 00000000..02382873
--- /dev/null
+++ b/tools/urlfieldtests/report_generation.py
@@ -0,0 +1,15 @@
+
+def write_to_report(listed_content: list, title: str, fname: str):
+    with open(fname, "a+") as file:
+        file.write(
+            "------------------------------------------------------------\n\n\t\t")
+        file.write(f"{title}\n\n")
+        file.write(
+            "------------------------------------------------------------\n\n")
+
+        counter = 1
+
+        for item in listed_content:
+            file.write(f"\t{counter}. {item[0]} : In table {item[2]} with pk={item[1]}\n")
+            counter += 1
+        file.close()
diff --git a/tools/urlfieldtests/urlscan.py b/tools/urlfieldtests/urlscan.py
new file mode 100755
index 00000000..2b394cf9
--- /dev/null
+++ b/tools/urlfieldtests/urlscan.py
@@ -0,0 +1,193 @@
+#!/usr/bin/env python3
+from datetime import datetime
+import psycopg2
+
+import requests
+import re
+import markdown
+
+from report_generation import write_to_report
+
+
+#
+# This script is used to scan content and url fields of specific tables
+# This script extracts these urls from the required fields and checks
+# if the urls are working or not.
+#
+# Example of test for a new table
+# def test_urls_<table_name>(<column_names,..>)
+#
+# You can use the common function urlvalidator(url) to check if the url
+# is working or not. To test markup content you can use the function
+# markup_urlvalidator(url)
+#
+
+
+def check_and_validate_markdown_urls(content):
+    pattern = re.compile(r'<a[\s]+([^>]+)>((?:.(?!\<\/a\>))*.)</a>')
+    content = markdown.markdown(content)
+    tag_matches = re.findall(pattern, content)
+    urls = []
+    for tag_data in tag_matches:
+        tag = tag_data[0]
+        tag = tag.replace('href=\"', "")
+        tag = tag[:tag.index('"')]
+        if not tag[0].isalpha():
+            continue
+        urls.append(tag)
+
+    broken_links = []
+    for url in urls:
+        if not urlvalidator(url):
+            broken_links.append(url)
+    return broken_links
+
+
+def urlvalidator(url):
+    broken_link_status_codes = [404, 410, 408, 504, 502, 503, 500, 403, 401, 400]
+    try:
+        res = requests.head(url, timeout=2.5)
+        if res.status_code in broken_link_status_codes:
+            return False
+    except Exception:
+        return False
+    return True
+
+
+# common function to connect to database
+def connect_to_db():
+    connection = psycopg2.connect(dbname="postgres", host="localhost", user="postgres", password="postgres")
+    return connection
+
+
+# Add tests from here ----------------------------------------------------
+
+# Check the url column in table core_organsation
+def test_urls_core_organisation():
+    conn = connect_to_db()
+    curs = conn.cursor()
+    table_name = 'core_organisation'
+    print(f"Checking table {table_name}")
+    curs.execute(f'SELECT id,url FROM {table_name};')
+
+    broken_links = []
+    for row in curs:
+        if not urlvalidator(row[1]):
+            broken_links.append([row[1], row[0], table_name])
+    conn.close()
+    return broken_links
+
+
+# Check the url and description columns in downloads_product
+def test_urls_downloads_product():
+    conn = connect_to_db()
+    curs = conn.cursor()
+    table_name = 'downloads_product'
+    print(f"Checking table {table_name}")
+    curs.execute(f'SELECT id,url,description FROM {table_name};')
+
+    broken_links = []
+    for row in curs:
+        if not urlvalidator(row[1]):
+            broken_links.append([row[1], row[0], table_name])
+
+        content = row[2]
+        brk_urls = check_and_validate_markdown_urls(content)
+        if len(brk_urls) > 0:
+            for url in brk_urls:
+                url = url + "(in markdown content)"
+                broken_links.append([url, row[0], table_name])
+    conn.close()
+    return broken_links
+
+
+# Check the content column in news_newsarticle
+def test_urls_news_newsarticle():
+    conn = connect_to_db()
+    curs = conn.cursor()
+    table_name = 'news_newsarticle'
+    print(f"Checking table {table_name}")
+    curs.execute(f'SELECT id,content FROM {table_name};')
+
+    broken_links = []
+    for row in curs:
+        content = row[1]
+        brk_urls = check_and_validate_markdown_urls(content)
+        if len(brk_urls) > 0:
+            for url in brk_urls:
+                url = url + "(in markdown content)"
+                broken_links.append([url, row[0], table_name])
+    conn.close()
+    return broken_links
+
+
+# Check the content column in events_event
+def test_urls_events_event():
+    conn = connect_to_db()
+    curs = conn.cursor()
+    table_name = 'events_event'
+    print(f"Checking table {table_name}")
+    curs.execute(f'SELECT id,summary,details FROM {table_name};')
+
+    broken_links = []
+    for row in curs:
+        content = row[1]
+        brk_urls = check_and_validate_markdown_urls(content)
+        if len(brk_urls) > 0:
+            for url in brk_urls:
+                url = url + "(in markdown field of details)"
+                broken_links.append([url, row[0], table_name])
+        content = row[2]
+        brk_urls = check_and_validate_markdown_urls(content)
+        if len(brk_urls) > 0:
+            for url in brk_urls:
+                url = url + "(in markdown field of details)"
+                broken_links.append([url, row[0], table_name])
+    conn.close()
+    return broken_links
+
+
+# Check the url column in profserv_professionalservice
+def test_urls_profserv_professionalservice():
+    conn = connect_to_db()
+    curs = conn.cursor()
+    table_name = 'profserv_professionalservice'
+    print(f"Checking table {table_name}")
+    curs.execute(f'SELECT id,url FROM {table_name};')
+
+    broken_links = []
+    for row in curs:
+        if not urlvalidator(row[1]):
+            broken_links.append([row[1], row[0], table_name])
+    conn.close()
+    return broken_links
+
+
+# -------------------------------
+
+if __name__ == '__main__':
+    final_list = []
+
+    org = test_urls_core_organisation()
+    if len(org) != 0:
+        final_list.extend(org)
+
+    products = test_urls_downloads_product()
+    if len(products) != 0:
+        final_list.extend(products)
+
+    news = test_urls_news_newsarticle()
+    if len(news) != 0:
+        final_list.extend(news)
+
+    profserv = test_urls_profserv_professionalservice()
+    if len(profserv) != 0:
+        final_list.extend(profserv)
+
+    events = test_urls_events_event()
+    if len(events) != 0:
+        final_list.extend(events)
+
+    fname = f"broken-links-{datetime.now()}.log"
+    write_to_report(final_list, "Broken Links", fname)
+    print(f"Please check {fname} for logs.")
